@@ -35,7 +35,8 @@ def cli(specs, output):
     env.filters["parameter_schema"] = openapi.parameter_schema
     env.filters["parameters"] = openapi.parameters
     env.filters["return_type"] = openapi.return_type
-    env.filters["safe_snake_case"] = openapi.safe_snake_case
+    env.filters["safe_snake_case"] = formatter.safe_snake_case
+    env.filters["docstring"] = formatter.docstring
 
     env.globals["enumerate"] = enumerate
     env.globals["package"] = PACKAGE_NAME
@@ -97,7 +98,7 @@ def cli(specs, output):
         package.mkdir(exist_ok=True)
 
         for name, model in models.items():
-            filename = openapi.safe_snake_case(name) + ".py"
+            filename = formatter.safe_snake_case(name) + ".py"
             model_path = package / "model" / filename
             model_path.parent.mkdir(parents=True, exist_ok=True)
             with model_path.open("w") as fp:
@@ -112,12 +113,14 @@ def cli(specs, output):
         with models_path.open("w") as fp:
             fp.write(models_j2.render(models=sorted(models)))
 
+        tags_by_name = {tag["name"]: tag for tag in spec["tags"]}
+
         for name, operations in apis.items():
-            filename = openapi.safe_snake_case(name) + "_api.py"
+            filename = formatter.safe_snake_case(name) + "_api.py"
             api_path = package / "api" / filename
             api_path.parent.mkdir(parents=True, exist_ok=True)
             with api_path.open("w") as fp:
-                fp.write(api_j2.render(name=name, operations=operations))
+                fp.write(api_j2.render(name=name, operations=operations, description=tags_by_name[name]["description"]))
 
         api_init_path = package / "api" / "__init__.py"
         with api_init_path.open("w") as fp:
