@@ -10,8 +10,7 @@ from yaml import CSafeLoader
 
 from . import formatter
 
-with (pathlib.Path(__file__).parent / "replacement.json").open() as f:
-    EDGE_CASES = json.load(f)
+PRIMITIVE_TYPES = ["string", "number", "boolean", "integer"]
 
 
 def load(filename):
@@ -20,20 +19,7 @@ def load(filename):
         return JsonRef.replace_refs(yaml.load(fp, Loader=CSafeLoader))
 
 
-def type_to_python(schema, alternative_name=None):
-    """Return Python type name for the type."""
-    name = formatter.get_name(schema)
-    if name:
-        if "enum" in schema:
-            return name
-        if schema.get("type", "object") in ("object", "array"):
-            return name
-
-    type_ = schema.get("type")
-    if type_ is None:
-        if "items" in schema:
-            type_ = "array"
-
+def type_ty_python_helper(type_, schema, alternative_name=None, in_list=False):
     if type_ is None:
         return "bool, date, datetime, dict, float, int, list, str, none_type"
 
@@ -51,7 +37,7 @@ def type_to_python(schema, alternative_name=None):
     elif type_ == "boolean":
         return "bool"
     elif type_ == "array":
-        return "[{}]".format(type_to_python(schema["items"]))
+        return "[{}]".format(type_to_python(schema["items"], in_list=True))
     elif type_ == "object":
         if "additionalProperties" in schema:
             nested_schema = schema["additionalProperties"]
@@ -76,6 +62,32 @@ def type_to_python(schema, alternative_name=None):
         raise ValueError(f"Unknown type {type_}")
 
 
+def type_to_python(schema, alternative_name=None, in_list=False):
+    """Return Python type name for the type."""
+    name = formatter.get_name(schema)
+    if name:
+        if "enum" in schema:
+            return name
+        if schema.get("type", "object") in ("object", "array"):
+            return name
+
+    type_ = schema.get("type")
+    if type_ is None:
+        if "oneOf" in schema and in_list:
+            type_ = ""
+            for child in schema["oneOf"]:
+                # We do not generate model for nested primitive oneOfs
+                if in_list and "items" in child and child["items"].get("type") in PRIMITIVE_TYPES:
+                    type_ += f"{type_ty_python_helper(child.get('type'), child, in_list=in_list)},"
+                else:
+                    type_ += f"{type_to_python(child, in_list=in_list)},"
+            return type_
+        if "items" in schema:
+            type_ = "array"
+
+    return type_ty_python_helper(type_, schema, alternative_name=alternative_name, in_list=in_list)
+
+
 def get_type_for_attribute(schema, attribute, current_name=None):
     """Return Python type name for the attribute."""
     child_schema = schema.get("properties", {}).get(attribute)
@@ -98,13 +110,19 @@ def get_type_for_items(schema):
     return name
 
 
-def get_type_for_parameter(parameter):
+def get_type_for_parameter(parameter, typing=False):
     """Return Python type name for the parameter."""
     if "content" in parameter:
         assert "in" not in parameter
         for content in parameter["content"].values():
-            return type_to_python(content["schema"])
-    return type_to_python(parameter.get("schema"))
+            data = type_to_python(content["schema"])
+            if typing:
+                data = data.replace("[", "List[")
+            return data
+    data = type_to_python(parameter.get("schema"))
+    if typing:
+        data = data.replace("[", "List[")
+    return data
 
 
 def get_enum_type(schema):
@@ -120,7 +138,7 @@ def get_enum_default(model):
     return model["enum"][0] if len(model["enum"]) == 1 else model.get("default")
 
 
-def child_models(schema, alternative_name=None, seen=None):
+def child_models(schema, alternative_name=None, seen=None, in_list=False):
     seen = seen or set()
     current_name = formatter.get_name(schema)
     name = current_name or alternative_name
@@ -133,6 +151,9 @@ def child_models(schema, alternative_name=None, seen=None):
     if "oneOf" in schema:
         has_sub_models = True
         for child in schema["oneOf"]:
+            # Don't generate models for nested primitive types
+            if in_list and child.get("type") in PRIMITIVE_TYPES:
+                return
             yield from child_models(child, seen=seen)
     if "anyOf" in schema:
         has_sub_models = True
@@ -144,6 +165,7 @@ def child_models(schema, alternative_name=None, seen=None):
             schema["items"],
             None,
             seen=seen,
+            in_list=True
         )
 
     if schema.get("type") == "object" or "properties" in schema or has_sub_models:
@@ -152,7 +174,7 @@ def child_models(schema, alternative_name=None, seen=None):
             return
 
         if name is None:
-            raise ValueError(f"Schema {schema} has no name")
+            return
 
         if name in seen:
             return
@@ -221,7 +243,7 @@ def models(spec):
 
 
 def get_references_for_model(model, model_name):
-    result = []
+    result = {}
     top_name = formatter.get_name(model) or model_name
     for key, definition in model.get("properties", {}).items():
         if (
@@ -231,33 +253,33 @@ def get_references_for_model(model, model_name):
         ):
             name = formatter.get_name(definition)
             if name:
-                result.append(name)
+                result[name] = None
             elif definition.get("properties") and top_name:
-                result.append(top_name + formatter.camel_case(key))
+                result[top_name + formatter.camel_case(key)] = None
             elif definition.get("additionalProperties"):
                 name = formatter.get_name(definition["additionalProperties"])
                 if name:
-                    result.append(name)
+                    result[name] = None
         elif definition.get("type") == "array":
             name = formatter.get_name(definition)
             if name:
-                result.append(name)
+                result[name] = None
             else:
                 name = formatter.get_name(definition.get("items"))
                 if name:
-                    result.append(name)
+                    result[name] = None
         elif definition.get("properties") and top_name:
-            result.append(top_name + formatter.camel_case(key))
+            result[top_name + formatter.camel_case(key)] = None
     if model.get("additionalProperties"):
         definition = model["additionalProperties"]
         name = formatter.get_name(definition)
         if name:
-            result.append(name)
+            result[name] = None
         elif definition.get("type") == "array":
             name = formatter.get_name(definition.get("items"))
             if name:
-                result.append(name)
-    return result
+                result[name] = None
+    return list(result)
 
 
 def get_oneof_parameters(model):
@@ -306,21 +328,6 @@ def apis(spec):
     return operations
 
 
-def operation(spec, operation_id):
-    for path in spec["paths"]:
-        for method in spec["paths"][path]:
-            operation = spec["paths"][path][method]
-            if operation["operationId"] == operation_id:
-                return operation
-    return None
-
-
-def safe_snake_case(value):
-    for token, replacement in EDGE_CASES.items():
-        value = value.replace(token, replacement)
-    return formatter.snake_case(value)
-
-
 def get_api_models(operations):
     seen = set()
     for _, _, operation in operations:
@@ -358,6 +365,11 @@ def get_api_models(operations):
                     if name and name not in seen:
                         seen.add(name)
                         yield name
+        if "x-pagination" in operation:
+            name = get_type_at_path(operation, operation["x-pagination"]["resultsPath"])
+            if name and name not in seen:
+                seen.add(name)
+                yield name
 
 
 def parameters(operation):
