@@ -2,7 +2,7 @@
 Set an AWS tag filter returns "OK" response
 """
 
-from datadog_api_client.v1 import ApiClient, Configuration
+from datadog_api_client import ApiClient, Configuration
 from datadog_api_client.v1.api.aws_integration_api import AWSIntegrationApi
 from datadog_api_client.v1.model.aws_namespace import AWSNamespace
 from datadog_api_client.v1.model.aws_tag_filter_create_request import AWSTagFilterCreateRequest
