@@ -3,7 +3,7 @@ Create a new dashboard with alert_value widget
 """
 
 from os import environ
-from datadog_api_client.v1 import ApiClient, Configuration
+from datadog_api_client import ApiClient, Configuration
 from datadog_api_client.v1.api.dashboards_api import DashboardsApi
 from datadog_api_client.v1.model.alert_value_widget_definition import AlertValueWidgetDefinition
 from datadog_api_client.v1.model.alert_value_widget_definition_type import AlertValueWidgetDefinitionType
