@@ -2,7 +2,7 @@
 Create a new dashboard with a formulas and functions change widget
 """
 
-from datadog_api_client.v1 import ApiClient, Configuration
+from datadog_api_client import ApiClient, Configuration
 from datadog_api_client.v1.api.dashboards_api import DashboardsApi
 from datadog_api_client.v1.model.change_widget_definition import ChangeWidgetDefinition
 from datadog_api_client.v1.model.change_widget_definition_type import ChangeWidgetDefinitionType
