@@ -1,8 +1,8 @@
 """
-Query the event stream returns "OK" response
+Get a list of events returns "OK" response
 """
 
-from datadog_api_client.v1 import ApiClient, Configuration
+from datadog_api_client import ApiClient, Configuration
 from datadog_api_client.v1.api.events_api import EventsApi
 
 configuration = Configuration()
