@@ -2,7 +2,7 @@
 List IP Ranges returns "OK" response
 """
 
-from datadog_api_client.v1 import ApiClient, Configuration
+from datadog_api_client import ApiClient, Configuration
 from datadog_api_client.v1.api.ip_ranges_api import IPRangesApi
 
 configuration = Configuration()
