@@ -2,7 +2,7 @@
 Edit an API key returns "OK" response
 """
 
-from datadog_api_client.v1 import ApiClient, Configuration
+from datadog_api_client import ApiClient, Configuration
 from datadog_api_client.v1.api.key_management_api import KeyManagementApi
 from datadog_api_client.v1.model.api_key import ApiKey
 
