@@ -2,7 +2,7 @@
 Update an index returns "OK" response
 """
 
-from datadog_api_client.v1 import ApiClient, Configuration
+from datadog_api_client import ApiClient, Configuration
 from datadog_api_client.v1.api.logs_indexes_api import LogsIndexesApi
 from datadog_api_client.v1.model.logs_exclusion import LogsExclusion
 from datadog_api_client.v1.model.logs_exclusion_filter import LogsExclusionFilter
