@@ -4,7 +4,7 @@ Search test logs returns "OK" response
 
 from datetime import datetime
 from dateutil.relativedelta import relativedelta
-from datadog_api_client.v1 import ApiClient, Configuration
+from datadog_api_client import ApiClient, Configuration
 from datadog_api_client.v1.api.logs_api import LogsApi
 from datadog_api_client.v1.model.logs_list_request import LogsListRequest
 from datadog_api_client.v1.model.logs_list_request_time import LogsListRequestTime
@@ -15,9 +15,9 @@ body = LogsListRequest(
     query="host:Test*",
     sort=LogsSort("asc"),
     time=LogsListRequestTime(
-        _from=(datetime.now() + relativedelta(hours=-1)).isoformat(timespec="seconds"),
+        _from=(datetime.now() + relativedelta(hours=-1)),
         timezone="Europe/Paris",
-        to=datetime.now().isoformat(timespec="seconds"),
+        to=datetime.now(),
     ),
 )
 
