@@ -2,7 +2,7 @@
 Send deflate logs returns "Response from server (always 200 empty JSON)." response
 """
 
-from datadog_api_client.v1 import ApiClient, Configuration
+from datadog_api_client import ApiClient, Configuration
 from datadog_api_client.v1.api.logs_api import LogsApi
 from datadog_api_client.v1.model.content_encoding import ContentEncoding
 from datadog_api_client.v1.model.http_log import HTTPLog
