@@ -2,7 +2,7 @@
 Create an SLO object returns "OK" response
 """
 
-from datadog_api_client.v1 import ApiClient, Configuration
+from datadog_api_client import ApiClient, Configuration
 from datadog_api_client.v1.api.service_level_objectives_api import ServiceLevelObjectivesApi
 from datadog_api_client.v1.model.service_level_objective_query import ServiceLevelObjectiveQuery
 from datadog_api_client.v1.model.service_level_objective_request import ServiceLevelObjectiveRequest
