@@ -4,7 +4,7 @@ Take graph snapshots returns "OK" response
 
 from datetime import datetime
 from dateutil.relativedelta import relativedelta
-from datadog_api_client.v1 import ApiClient, Configuration
+from datadog_api_client import ApiClient, Configuration
 from datadog_api_client.v1.api.snapshots_api import SnapshotsApi
 
 configuration = Configuration()
@@ -15,6 +15,8 @@ with ApiClient(configuration) as api_client:
         start=int((datetime.now() + relativedelta(days=-1)).timestamp()),
         end=int(datetime.now().timestamp()),
         title="System load",
+        height=400,
+        width=600,
     )
 
     print(response)
