@@ -2,7 +2,7 @@
 Client is resilient to enum and oneOf deserialization errors
 """
 
-from datadog_api_client.v1 import ApiClient, Configuration
+from datadog_api_client import ApiClient, Configuration
 from datadog_api_client.v1.api.synthetics_api import SyntheticsApi
 
 configuration = Configuration()
