@@ -2,7 +2,7 @@
 Get usage across your multi-org account returns "OK" response
 """
 
-from datadog_api_client.v1 import ApiClient, Configuration
+from datadog_api_client import ApiClient, Configuration
 from datadog_api_client.v1.api.usage_metering_api import UsageMeteringApi
 from datetime import datetime
 from dateutil.tz import tzutc
