@@ -2,7 +2,7 @@
 Get a custom variable returns "OK" response
 """
 
-from datadog_api_client.v1 import ApiClient, Configuration
+from datadog_api_client import ApiClient, Configuration
 from datadog_api_client.v1.api.webhooks_integration_api import WebhooksIntegrationApi
 
 configuration = Configuration()
