@@ -2,7 +2,7 @@
 Create a Cloud Workload Security Agent rule returns "OK" response
 """
 
-from datadog_api_client.v2 import ApiClient, Configuration
+from datadog_api_client import ApiClient, Configuration
 from datadog_api_client.v2.api.cloud_workload_security_api import CloudWorkloadSecurityApi
 from datadog_api_client.v2.model.cloud_workload_security_agent_rule_create_attributes import (
     CloudWorkloadSecurityAgentRuleCreateAttributes,
