@@ -3,7 +3,7 @@ Delete a Cloud Workload Security Agent rule returns "OK" response
 """
 
 from os import environ
-from datadog_api_client.v2 import ApiClient, Configuration
+from datadog_api_client import ApiClient, Configuration
 from datadog_api_client.v2.api.cloud_workload_security_api import CloudWorkloadSecurityApi
 
 # there is a valid "agent_rule" in the system
