@@ -3,7 +3,7 @@ Update a Cloud Workload Security Agent rule returns "OK" response
 """
 
 from os import environ
-from datadog_api_client.v2 import ApiClient, Configuration
+from datadog_api_client import ApiClient, Configuration
 from datadog_api_client.v2.api.cloud_workload_security_api import CloudWorkloadSecurityApi
 from datadog_api_client.v2.model.cloud_workload_security_agent_rule_type import CloudWorkloadSecurityAgentRuleType
 from datadog_api_client.v2.model.cloud_workload_security_agent_rule_update_attributes import (
