@@ -2,7 +2,7 @@
 Update archive order returns "OK" response
 """
 
-from datadog_api_client.v2 import ApiClient, Configuration
+from datadog_api_client import ApiClient, Configuration
 from datadog_api_client.v2.api.logs_archives_api import LogsArchivesApi
 from datadog_api_client.v2.model.logs_archive_order import LogsArchiveOrder
 from datadog_api_client.v2.model.logs_archive_order_attributes import LogsArchiveOrderAttributes
