@@ -3,7 +3,7 @@ Update a tag configuration returns "OK" response
 """
 
 from os import environ
-from datadog_api_client.v2 import ApiClient, Configuration
+from datadog_api_client import ApiClient, Configuration
 from datadog_api_client.v2.api.metrics_api import MetricsApi
 from datadog_api_client.v2.model.metric_tag_configuration_type import MetricTagConfigurationType
 from datadog_api_client.v2.model.metric_tag_configuration_update_attributes import (
@@ -28,7 +28,6 @@ body = MetricTagConfigurationUpdateRequest(
 )
 
 configuration = Configuration()
-configuration.unstable_operations["update_tag_configuration"] = True
 with ApiClient(configuration) as api_client:
     api_instance = MetricsApi(api_client)
     response = api_instance.update_tag_configuration(metric_name=METRIC_TAG_CONFIGURATION_DATA_ID, body=body)
