@@ -3,7 +3,7 @@ Delete an app key owned by this service account returns "No Content" response
 """
 
 from os import environ
-from datadog_api_client.v2 import ApiClient, Configuration
+from datadog_api_client import ApiClient, Configuration
 from datadog_api_client.v2.api.service_accounts_api import ServiceAccountsApi
 
 # there is a valid "service_account_user" in the system
