@@ -3,7 +3,7 @@ Create a service account returns "OK" response
 """
 
 from os import environ
-from datadog_api_client.v2 import ApiClient, Configuration
+from datadog_api_client import ApiClient, Configuration
 from datadog_api_client.v2.api.users_api import UsersApi
 from datadog_api_client.v2.model.relationship_to_role_data import RelationshipToRoleData
 from datadog_api_client.v2.model.relationship_to_roles import RelationshipToRoles
