@@ -1,13 +1,23 @@
 # Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
 # This product includes software developed at Datadog (https://www.datadoghq.com/).
 # Copyright 2019-Present Datadog, Inc.
+from __future__ import annotations
 
+from typing import Any, Dict, Union
 
 from datadog_api_client.api_client import ApiClient, Endpoint as _Endpoint
+from datadog_api_client.model_utils import (
+    UnsetType,
+    unset,
+)
 from datadog_api_client.v1.model.graph_snapshot import GraphSnapshot
 
 
 class SnapshotsApi:
+    """
+    Take graph snapshots using the API.
+    """
+
     def __init__(self, api_client=None):
         if api_client is None:
             api_client = ApiClient()
@@ -56,6 +66,16 @@ class SnapshotsApi:
                     "attribute": "title",
                     "location": "query",
                 },
+                "height": {
+                    "openapi_types": (int,),
+                    "attribute": "height",
+                    "location": "query",
+                },
+                "width": {
+                    "openapi_types": (int,),
+                    "attribute": "width",
+                    "location": "query",
+                },
             },
             headers_map={
                 "accept": ["application/json"],
@@ -64,17 +84,22 @@ class SnapshotsApi:
             api_client=api_client,
         )
 
-    def get_graph_snapshot(self, start, end, **kwargs):
+    def get_graph_snapshot(
+        self,
+        start: int,
+        end: int,
+        *,
+        metric_query: Union[str, UnsetType] = unset,
+        event_query: Union[str, UnsetType] = unset,
+        graph_def: Union[str, UnsetType] = unset,
+        title: Union[str, UnsetType] = unset,
+        height: Union[int, UnsetType] = unset,
+        width: Union[int, UnsetType] = unset,
+    ) -> GraphSnapshot:
         """Take graph snapshots.
 
         Take graph snapshots.
-        **Note**: When a snapshot is created, there is some delay before it is available.
-
-        This method makes a synchronous HTTP request by default. To make an
-        asynchronous HTTP request, please pass async_req=True.
-
-        >>> thread = api.get_graph_snapshot(start, end, async_req=True)
-        >>> result = thread.get()
+        **Note** : When a snapshot is created, there is some delay before it is available.
 
         :param start: The POSIX timestamp of the start of the query.
         :type start: int
@@ -84,41 +109,39 @@ class SnapshotsApi:
         :type metric_query: str, optional
         :param event_query: A query that adds event bands to the graph.
         :type event_query: str, optional
-        :param graph_def: A JSON document defining the graph. `graph_def` can be used instead of `metric_query`.
-            The JSON document uses the [grammar defined here](https://docs.datadoghq.com/graphing/graphing_json/#grammar)
+        :param graph_def: A JSON document defining the graph. ``graph_def`` can be used instead of ``metric_query``.
+            The JSON document uses the `grammar defined here <https://docs.datadoghq.com/graphing/graphing_json/#grammar>`_
             and should be formatted to a single line then URL encoded.
         :type graph_def: str, optional
         :param title: A title for the graph. If no title is specified, the graph does not have a title.
         :type title: str, optional
-        :param _return_http_data_only: Response data without head status
-            code and headers. Default is True.
-        :type _return_http_data_only: bool
-        :param _preload_content: If False, the urllib3.HTTPResponse object
-            will be returned without reading/decoding response data.
-            Default is True.
-        :type _preload_content: bool
-        :param _request_timeout: Timeout setting for this request. If one
-            number provided, it will be total request timeout. It can also be a
-            pair (tuple) of (connection, read) timeouts.  Default is None.
-        :type _request_timeout: float/tuple
-        :param _check_input_type: Specifies if type checking should be done one
-            the data sent to the server. Default is True.
-        :type _check_input_type: bool
-        :param _check_return_type: Specifies if type checking should be done
-            one the data received from the server. Default is True.
-        :type _check_return_type: bool
-        :param _host_index: Specifies the index of the server that we want to
-            use. Default is read from the configuration.
-        :type _host_index: int/None
-        :param async_req: Execute request asynchronously.
-        :type async_req: bool
-
-        :return: If the method is called asynchronously, returns the request thread.
+        :param height: The height of the graph. If no height is specified, the graph's original height is used.
+        :type height: int, optional
+        :param width: The width of the graph. If no width is specified, the graph's original width is used.
+        :type width: int, optional
         :rtype: GraphSnapshot
         """
-        kwargs = self._get_graph_snapshot_endpoint.default_arguments(kwargs)
+        kwargs: Dict[str, Any] = {}
+        if metric_query is not unset:
+            kwargs["metric_query"] = metric_query
+
         kwargs["start"] = start
 
         kwargs["end"] = end
 
+        if event_query is not unset:
+            kwargs["event_query"] = event_query
+
+        if graph_def is not unset:
+            kwargs["graph_def"] = graph_def
+
+        if title is not unset:
+            kwargs["title"] = title
+
+        if height is not unset:
+            kwargs["height"] = height
+
+        if width is not unset:
+            kwargs["width"] = width
+
         return self._get_graph_snapshot_endpoint.call_with_http_info(**kwargs)
