@@ -3,18 +3,15 @@
 # Copyright 2019-Present Datadog, Inc.
 
 
-from datadog_api_client.v1.model_utils import (
+from datadog_api_client.model_utils import (
     ModelNormal,
     cached_property,
 )
 
 
 class AWSAccountCreateResponse(ModelNormal):
-
-    validations = {}
-
     @cached_property
-    def openapi_types():
+    def openapi_types(_):
         return {
             "external_id": (str,),
         }
@@ -23,8 +20,6 @@ class AWSAccountCreateResponse(ModelNormal):
         "external_id": "external_id",
     }
 
-    read_only_vars = {}
-
     def __init__(self, *args, **kwargs):
         """
         The Response returned by the AWS Create Account call.
