@@ -9,16 +9,11 @@ from datadog_api_client.model_utils import (
 )
 
 
-def lazy_import():
-    from datadog_api_client.v1.model.aws_namespace import AWSNamespace
-
-    globals()["AWSNamespace"] = AWSNamespace
-
-
 class AWSTagFilterDeleteRequest(ModelNormal):
     @cached_property
     def openapi_types(_):
-        lazy_import()
+        from datadog_api_client.v1.model.aws_namespace import AWSNamespace
+
         return {
             "account_id": (str,),
             "namespace": (AWSNamespace,),
