@@ -24,9 +24,9 @@ class CancelDowntimesByScopeRequest(ModelNormal):
         """
         Cancel downtimes according to scope.
 
-        :param scope: The scope(s) to which the downtime applies. For example, `host:app2`.
-            Provide multiple scopes as a comma-separated list like `env:dev,env:prod`.
-            The resulting downtime applies to sources that matches ALL provided scopes (`env:dev` **AND** `env:prod`).
+        :param scope: The scope(s) to which the downtime applies. For example, ``host:app2``.
+            Provide multiple scopes as a comma-separated list like ``env:dev,env:prod``.
+            The resulting downtime applies to sources that matches ALL provided scopes ( ``env:dev`` **AND** ``env:prod`` ).
         :type scope: str
         """
         super().__init__(kwargs)
