@@ -3,18 +3,15 @@
 # Copyright 2019-Present Datadog, Inc.
 
 
-from datadog_api_client.v1.model_utils import (
+from datadog_api_client.model_utils import (
     ModelNormal,
     cached_property,
 )
 
 
 class CheckCanDeleteSLOResponseData(ModelNormal):
-
-    validations = {}
-
     @cached_property
-    def openapi_types():
+    def openapi_types(_):
         return {
             "ok": ([str],),
         }
@@ -23,8 +20,6 @@ class CheckCanDeleteSLOResponseData(ModelNormal):
         "ok": "ok",
     }
 
-    read_only_vars = {}
-
     def __init__(self, *args, **kwargs):
         """
         An array of service level objective objects.
