@@ -9,16 +9,11 @@ from datadog_api_client.model_utils import (
 )
 
 
-def lazy_import():
-    from datadog_api_client.v1.model.dashboard_resource_type import DashboardResourceType
-
-    globals()["DashboardResourceType"] = DashboardResourceType
-
-
 class DashboardBulkActionData(ModelNormal):
     @cached_property
     def openapi_types(_):
-        lazy_import()
+        from datadog_api_client.v1.model.dashboard_resource_type import DashboardResourceType
+
         return {
             "id": (str,),
             "type": (DashboardResourceType,),
