@@ -9,16 +9,11 @@ from datadog_api_client.model_utils import (
 )
 
 
-def lazy_import():
-    from datadog_api_client.v1.model.dashboard_bulk_action_data_list import DashboardBulkActionDataList
-
-    globals()["DashboardBulkActionDataList"] = DashboardBulkActionDataList
-
-
 class DashboardRestoreRequest(ModelNormal):
     @cached_property
     def openapi_types(_):
-        lazy_import()
+        from datadog_api_client.v1.model.dashboard_bulk_action_data_list import DashboardBulkActionDataList
+
         return {
             "data": (DashboardBulkActionDataList,),
         }
