@@ -11,16 +11,11 @@ from datadog_api_client.model_utils import (
 )
 
 
-def lazy_import():
-    from datadog_api_client.v1.model.dashboard_layout_type import DashboardLayoutType
-
-    globals()["DashboardLayoutType"] = DashboardLayoutType
-
-
 class DashboardSummaryDefinition(ModelNormal):
     @cached_property
     def openapi_types(_):
-        lazy_import()
+        from datadog_api_client.v1.model.dashboard_layout_type import DashboardLayoutType
+
         return {
             "author_handle": (str,),
             "created_at": (datetime,),
