@@ -9,18 +9,13 @@ from datadog_api_client.model_utils import (
 )
 
 
-def lazy_import():
-    from datadog_api_client.v1.model.dashboard_template_variable_preset_value import (
-        DashboardTemplateVariablePresetValue,
-    )
-
-    globals()["DashboardTemplateVariablePresetValue"] = DashboardTemplateVariablePresetValue
-
-
 class DashboardTemplateVariablePreset(ModelNormal):
     @cached_property
     def openapi_types(_):
-        lazy_import()
+        from datadog_api_client.v1.model.dashboard_template_variable_preset_value import (
+            DashboardTemplateVariablePresetValue,
+        )
+
         return {
             "name": (str,),
             "template_variables": ([DashboardTemplateVariablePresetValue],),
