@@ -9,22 +9,14 @@ from datadog_api_client.model_utils import (
 )
 
 
-def lazy_import():
-    from datadog_api_client.v1.model.widget_event_size import WidgetEventSize
-    from datadog_api_client.v1.model.widget_time import WidgetTime
-    from datadog_api_client.v1.model.widget_text_align import WidgetTextAlign
-    from datadog_api_client.v1.model.event_stream_widget_definition_type import EventStreamWidgetDefinitionType
-
-    globals()["WidgetEventSize"] = WidgetEventSize
-    globals()["WidgetTime"] = WidgetTime
-    globals()["WidgetTextAlign"] = WidgetTextAlign
-    globals()["EventStreamWidgetDefinitionType"] = EventStreamWidgetDefinitionType
-
-
 class EventStreamWidgetDefinition(ModelNormal):
     @cached_property
     def openapi_types(_):
-        lazy_import()
+        from datadog_api_client.v1.model.widget_event_size import WidgetEventSize
+        from datadog_api_client.v1.model.widget_time import WidgetTime
+        from datadog_api_client.v1.model.widget_text_align import WidgetTextAlign
+        from datadog_api_client.v1.model.event_stream_widget_definition_type import EventStreamWidgetDefinitionType
+
         return {
             "event_size": (WidgetEventSize,),
             "query": (str,),
