@@ -9,18 +9,13 @@ from datadog_api_client.model_utils import (
 )
 
 
-def lazy_import():
-    from datadog_api_client.v1.model.formula_and_function_event_query_group_by_sort import (
-        FormulaAndFunctionEventQueryGroupBySort,
-    )
-
-    globals()["FormulaAndFunctionEventQueryGroupBySort"] = FormulaAndFunctionEventQueryGroupBySort
-
-
 class FormulaAndFunctionEventQueryGroupBy(ModelNormal):
     @cached_property
     def openapi_types(_):
-        lazy_import()
+        from datadog_api_client.v1.model.formula_and_function_event_query_group_by_sort import (
+            FormulaAndFunctionEventQueryGroupBySort,
+        )
+
         return {
             "facet": (str,),
             "limit": (int,),
