@@ -9,18 +9,16 @@ from datadog_api_client.model_utils import (
 )
 
 
-def lazy_import():
-    from datadog_api_client.v1.model.formula_and_function_metric_aggregation import FormulaAndFunctionMetricAggregation
-    from datadog_api_client.v1.model.formula_and_function_metric_data_source import FormulaAndFunctionMetricDataSource
-
-    globals()["FormulaAndFunctionMetricAggregation"] = FormulaAndFunctionMetricAggregation
-    globals()["FormulaAndFunctionMetricDataSource"] = FormulaAndFunctionMetricDataSource
-
-
 class FormulaAndFunctionMetricQueryDefinition(ModelNormal):
     @cached_property
     def openapi_types(_):
-        lazy_import()
+        from datadog_api_client.v1.model.formula_and_function_metric_aggregation import (
+            FormulaAndFunctionMetricAggregation,
+        )
+        from datadog_api_client.v1.model.formula_and_function_metric_data_source import (
+            FormulaAndFunctionMetricDataSource,
+        )
+
         return {
             "aggregator": (FormulaAndFunctionMetricAggregation,),
             "data_source": (FormulaAndFunctionMetricDataSource,),
