@@ -9,18 +9,6 @@ from datadog_api_client.model_utils import (
 )
 
 
-def lazy_import():
-    from datadog_api_client.v1.model.funnel_widget_request import FunnelWidgetRequest
-    from datadog_api_client.v1.model.widget_time import WidgetTime
-    from datadog_api_client.v1.model.widget_text_align import WidgetTextAlign
-    from datadog_api_client.v1.model.funnel_widget_definition_type import FunnelWidgetDefinitionType
-
-    globals()["FunnelWidgetRequest"] = FunnelWidgetRequest
-    globals()["WidgetTime"] = WidgetTime
-    globals()["WidgetTextAlign"] = WidgetTextAlign
-    globals()["FunnelWidgetDefinitionType"] = FunnelWidgetDefinitionType
-
-
 class FunnelWidgetDefinition(ModelNormal):
     validations = {
         "requests": {
@@ -31,7 +19,11 @@ class FunnelWidgetDefinition(ModelNormal):
 
     @cached_property
     def openapi_types(_):
-        lazy_import()
+        from datadog_api_client.v1.model.funnel_widget_request import FunnelWidgetRequest
+        from datadog_api_client.v1.model.widget_time import WidgetTime
+        from datadog_api_client.v1.model.widget_text_align import WidgetTextAlign
+        from datadog_api_client.v1.model.funnel_widget_definition_type import FunnelWidgetDefinitionType
+
         return {
             "requests": ([FunnelWidgetRequest],),
             "time": (WidgetTime,),
@@ -54,7 +46,6 @@ class FunnelWidgetDefinition(ModelNormal):
         """
         The funnel visualization displays a funnel of user sessions that maps a sequence of view navigation and user interaction in your application.
 
-
         :param requests: Request payload used to query items.
         :type requests: [FunnelWidgetRequest]
 
