@@ -3,18 +3,15 @@
 # Copyright 2019-Present Datadog, Inc.
 
 
-from datadog_api_client.v1.model_utils import (
+from datadog_api_client.model_utils import (
     ModelNormal,
     cached_property,
 )
 
 
 class GeomapWidgetDefinitionStyle(ModelNormal):
-
-    validations = {}
-
     @cached_property
-    def openapi_types():
+    def openapi_types(_):
         return {
             "palette": (str,),
             "palette_flip": (bool,),
@@ -25,8 +22,6 @@ class GeomapWidgetDefinitionStyle(ModelNormal):
         "palette_flip": "palette_flip",
     }
 
-    read_only_vars = {}
-
     def __init__(self, palette, palette_flip, *args, **kwargs):
         """
         The style to apply to the widget.
