@@ -28,15 +28,15 @@ class GraphSnapshot(ModelNormal):
         """
         Object representing a graph snapshot.
 
-        :param graph_def: A JSON document defining the graph. `graph_def` can be used instead of `metric_query`.
-            The JSON document uses the [grammar defined here](https://docs.datadoghq.com/graphing/graphing_json/#grammar)
+        :param graph_def: A JSON document defining the graph. ``graph_def`` can be used instead of ``metric_query``.
+            The JSON document uses the `grammar defined here <https://docs.datadoghq.com/graphing/graphing_json/#grammar>`_
             and should be formatted to a single line then URL encoded.
         :type graph_def: str, optional
 
-        :param metric_query: The metric query. One of `metric_query` or `graph_def` is required.
+        :param metric_query: The metric query. One of ``metric_query`` or ``graph_def`` is required.
         :type metric_query: str, optional
 
-        :param snapshot_url: URL of your [graph snapshot](https://docs.datadoghq.com/metrics/explorer/#snapshot).
+        :param snapshot_url: URL of your `graph snapshot <https://docs.datadoghq.com/metrics/explorer/#snapshot>`_.
         :type snapshot_url: str, optional
         """
         super().__init__(kwargs)
