@@ -9,24 +9,6 @@ from datadog_api_client.model_utils import (
 )
 
 
-def lazy_import():
-    from datadog_api_client.v1.model.widget_custom_link import WidgetCustomLink
-    from datadog_api_client.v1.model.widget_event import WidgetEvent
-    from datadog_api_client.v1.model.heat_map_widget_request import HeatMapWidgetRequest
-    from datadog_api_client.v1.model.widget_time import WidgetTime
-    from datadog_api_client.v1.model.widget_text_align import WidgetTextAlign
-    from datadog_api_client.v1.model.heat_map_widget_definition_type import HeatMapWidgetDefinitionType
-    from datadog_api_client.v1.model.widget_axis import WidgetAxis
-
-    globals()["WidgetCustomLink"] = WidgetCustomLink
-    globals()["WidgetEvent"] = WidgetEvent
-    globals()["HeatMapWidgetRequest"] = HeatMapWidgetRequest
-    globals()["WidgetTime"] = WidgetTime
-    globals()["WidgetTextAlign"] = WidgetTextAlign
-    globals()["HeatMapWidgetDefinitionType"] = HeatMapWidgetDefinitionType
-    globals()["WidgetAxis"] = WidgetAxis
-
-
 class HeatMapWidgetDefinition(ModelNormal):
     validations = {
         "requests": {
@@ -37,7 +19,14 @@ class HeatMapWidgetDefinition(ModelNormal):
 
     @cached_property
     def openapi_types(_):
-        lazy_import()
+        from datadog_api_client.v1.model.widget_custom_link import WidgetCustomLink
+        from datadog_api_client.v1.model.widget_event import WidgetEvent
+        from datadog_api_client.v1.model.heat_map_widget_request import HeatMapWidgetRequest
+        from datadog_api_client.v1.model.widget_time import WidgetTime
+        from datadog_api_client.v1.model.widget_text_align import WidgetTextAlign
+        from datadog_api_client.v1.model.heat_map_widget_definition_type import HeatMapWidgetDefinitionType
+        from datadog_api_client.v1.model.widget_axis import WidgetAxis
+
         return {
             "custom_links": ([WidgetCustomLink],),
             "events": ([WidgetEvent],),
