@@ -9,16 +9,11 @@ from datadog_api_client.model_utils import (
 )
 
 
-def lazy_import():
-    from datadog_api_client.v1.model.host import Host
-
-    globals()["Host"] = Host
-
-
 class HostListResponse(ModelNormal):
     @cached_property
     def openapi_types(_):
-        lazy_import()
+        from datadog_api_client.v1.model.host import Host
+
         return {
             "host_list": ([Host],),
             "total_matching": (int,),
