@@ -9,18 +9,11 @@ from datadog_api_client.model_utils import (
 )
 
 
-def lazy_import():
-    from datadog_api_client.v1.model.host_map_request import HostMapRequest
-    from datadog_api_client.v1.model.host_map_request import HostMapRequest
-
-    globals()["HostMapRequest"] = HostMapRequest
-    globals()["HostMapRequest"] = HostMapRequest
-
-
 class HostMapWidgetDefinitionRequests(ModelNormal):
     @cached_property
     def openapi_types(_):
-        lazy_import()
+        from datadog_api_client.v1.model.host_map_request import HostMapRequest
+
         return {
             "fill": (HostMapRequest,),
             "size": (HostMapRequest,),
