@@ -10,18 +10,12 @@ from datadog_api_client.model_utils import (
 )
 
 
-def lazy_import():
-    from datadog_api_client.v1.model.usage_attribution_tag_names import UsageAttributionTagNames
-    from datadog_api_client.v1.model.hourly_usage_attribution_usage_type import HourlyUsageAttributionUsageType
-
-    globals()["UsageAttributionTagNames"] = UsageAttributionTagNames
-    globals()["HourlyUsageAttributionUsageType"] = HourlyUsageAttributionUsageType
-
-
 class HourlyUsageAttributionBody(ModelNormal):
     @cached_property
     def openapi_types(_):
-        lazy_import()
+        from datadog_api_client.v1.model.usage_attribution_tag_names import UsageAttributionTagNames
+        from datadog_api_client.v1.model.hourly_usage_attribution_usage_type import HourlyUsageAttributionUsageType
+
         return {
             "hour": (datetime,),
             "org_name": (str,),
@@ -57,10 +51,14 @@ class HourlyUsageAttributionBody(ModelNormal):
         :param public_id: The organization public ID.
         :type public_id: str, optional
 
-        :param tag_config_source: The source of the usage attribution tag configuration and the selected tags in the format of `<source_org_name>:::<selected tag 1>///<selected tag 2>///<selected tag 3>`.
+        :param tag_config_source: The source of the usage attribution tag configuration and the selected tags in the format of ``<source_org_name>:::<selected tag 1>///<selected tag 2>///<selected tag 3>``.
         :type tag_config_source: str, optional
 
-        :param tags: Usage Summary by tag name.
+        :param tags: Tag keys and values.
+
+            A ``null`` value here means that the requested tag breakdown cannot be applied because it does not match the `tags
+            configured for usage attribution <https://docs.datadoghq.com/account_management/billing/usage_attribution/#getting-started>`_.
+            In this scenario the API returns the total usage, not broken down by tags.
         :type tags: UsageAttributionTagNames, optional
 
         :param total_usage_sum: Total product usage for the given tags within the hour.
