@@ -3,7 +3,7 @@
 # Copyright 2019-Present Datadog, Inc.
 
 
-from datadog_api_client.v1.model_utils import (
+from datadog_api_client.model_utils import (
     ModelNormal,
     cached_property,
     file_type,
@@ -11,11 +11,8 @@ from datadog_api_client.v1.model_utils import (
 
 
 class IdpFormData(ModelNormal):
-
-    validations = {}
-
     @cached_property
-    def openapi_types():
+    def openapi_types(_):
         return {
             "idp_file": (file_type,),
         }
@@ -24,8 +21,6 @@ class IdpFormData(ModelNormal):
         "idp_file": "idp_file",
     }
 
-    read_only_vars = {}
-
     def __init__(self, idp_file, *args, **kwargs):
         """
         Object describing the IdP configuration.
