@@ -3,18 +3,15 @@
 # Copyright 2019-Present Datadog, Inc.
 
 
-from datadog_api_client.v1.model_utils import (
+from datadog_api_client.model_utils import (
     ModelNormal,
     cached_property,
 )
 
 
 class IPPrefixesAPM(ModelNormal):
-
-    validations = {}
-
     @cached_property
-    def openapi_types():
+    def openapi_types(_):
         return {
             "prefixes_ipv4": ([str],),
             "prefixes_ipv6": ([str],),
@@ -25,8 +22,6 @@ class IPPrefixesAPM(ModelNormal):
         "prefixes_ipv6": "prefixes_ipv6",
     }
 
-    read_only_vars = {}
-
     def __init__(self, *args, **kwargs):
         """
         Available prefix information for the APM endpoints.
