@@ -9,16 +9,11 @@ from datadog_api_client.model_utils import (
 )
 
 
-def lazy_import():
-    from datadog_api_client.v1.model.log_query_definition_group_by_sort import LogQueryDefinitionGroupBySort
-
-    globals()["LogQueryDefinitionGroupBySort"] = LogQueryDefinitionGroupBySort
-
-
 class LogQueryDefinitionGroupBy(ModelNormal):
     @cached_property
     def openapi_types(_):
-        lazy_import()
+        from datadog_api_client.v1.model.log_query_definition_group_by_sort import LogQueryDefinitionGroupBySort
+
         return {
             "facet": (str,),
             "limit": (int,),
