@@ -9,16 +9,11 @@ from datadog_api_client.model_utils import (
 )
 
 
-def lazy_import():
-    from datadog_api_client.v1.model.logs_date_remapper_type import LogsDateRemapperType
-
-    globals()["LogsDateRemapperType"] = LogsDateRemapperType
-
-
 class LogsDateRemapper(ModelNormal):
     @cached_property
     def openapi_types(_):
-        lazy_import()
+        from datadog_api_client.v1.model.logs_date_remapper_type import LogsDateRemapperType
+
         return {
             "is_enabled": (bool,),
             "name": (str,),
@@ -37,12 +32,14 @@ class LogsDateRemapper(ModelNormal):
         """
         As Datadog receives logs, it timestamps them using the value(s) from any of these default attributes.
 
-          - `timestamp`
-          - `date`
-          - `_timestamp`
-          - `Timestamp`
-          - `eventTime`
-          - `published_date`
+
+        * ``timestamp``
+        * ``date``
+        * ``_timestamp``
+        * ``Timestamp``
+        * ``eventTime``
+        *
+          ``published_date``
 
           If your logs put their dates in an attribute not in this list,
           use the log date Remapper Processor to define their date attribute as the official log timestamp.
