@@ -9,18 +9,12 @@ from datadog_api_client.model_utils import (
 )
 
 
-def lazy_import():
-    from datadog_api_client.v1.model.logs_exclusion import LogsExclusion
-    from datadog_api_client.v1.model.logs_filter import LogsFilter
-
-    globals()["LogsExclusion"] = LogsExclusion
-    globals()["LogsFilter"] = LogsFilter
-
-
 class LogsIndexUpdateRequest(ModelNormal):
     @cached_property
     def openapi_types(_):
-        lazy_import()
+        from datadog_api_client.v1.model.logs_exclusion import LogsExclusion
+        from datadog_api_client.v1.model.logs_filter import LogsFilter
+
         return {
             "daily_limit": (int,),
             "disable_daily_limit": (bool,),
@@ -44,9 +38,9 @@ class LogsIndexUpdateRequest(ModelNormal):
         :param daily_limit: The number of log events you can send in this index per day before you are rate-limited.
         :type daily_limit: int, optional
 
-        :param disable_daily_limit: If true, sets the `daily_limit` value to null and the index is not limited on a daily basis (any
-            specified `daily_limit` value in the request is ignored). If false or omitted, the index's current
-            `daily_limit` is maintained.
+        :param disable_daily_limit: If true, sets the ``daily_limit`` value to null and the index is not limited on a daily basis (any
+            specified ``daily_limit`` value in the request is ignored). If false or omitted, the index's current
+            ``daily_limit`` is maintained.
         :type disable_daily_limit: bool, optional
 
         :param exclusion_filters: An array of exclusion objects. The logs are tested against the query of each filter,
