@@ -3,18 +3,15 @@
 # Copyright 2019-Present Datadog, Inc.
 
 
-from datadog_api_client.v1.model_utils import (
+from datadog_api_client.model_utils import (
     ModelNormal,
     cached_property,
 )
 
 
 class LogsIndexesOrder(ModelNormal):
-
-    validations = {}
-
     @cached_property
-    def openapi_types():
+    def openapi_types(_):
         return {
             "index_names": ([str],),
         }
@@ -23,8 +20,6 @@ class LogsIndexesOrder(ModelNormal):
         "index_names": "index_names",
     }
 
-    read_only_vars = {}
-
     def __init__(self, index_names, *args, **kwargs):
         """
         Object containing the ordered list of log index names.
