@@ -9,14 +9,6 @@ from datadog_api_client.model_utils import (
 )
 
 
-def lazy_import():
-    from datadog_api_client.v1.model.logs_sort import LogsSort
-    from datadog_api_client.v1.model.logs_list_request_time import LogsListRequestTime
-
-    globals()["LogsSort"] = LogsSort
-    globals()["LogsListRequestTime"] = LogsListRequestTime
-
-
 class LogsListRequest(ModelNormal):
     validations = {
         "limit": {
@@ -26,7 +18,9 @@ class LogsListRequest(ModelNormal):
 
     @cached_property
     def openapi_types(_):
-        lazy_import()
+        from datadog_api_client.v1.model.logs_sort import LogsSort
+        from datadog_api_client.v1.model.logs_list_request_time import LogsListRequestTime
+
         return {
             "index": (str,),
             "limit": (int,),
@@ -59,13 +53,13 @@ class LogsListRequest(ModelNormal):
         :param query: The search query - following the log search syntax.
         :type query: str, optional
 
-        :param sort: Time-ascending `asc` or time-descending `desc`results.
+        :param sort: Time-ascending ``asc`` or time-descending ``desc`` results.
         :type sort: LogsSort, optional
 
-        :param start_at: Hash identifier of the first log to return in the list, available in a log `id` attribute.
+        :param start_at: Hash identifier of the first log to return in the list, available in a log ``id`` attribute.
             This parameter is used for the pagination feature.
 
-            **Note**: This parameter is ignored if the corresponding log
+            **Note** : This parameter is ignored if the corresponding log
             is out of the scope of the specified time window.
         :type start_at: str, optional
 
