@@ -24,7 +24,7 @@ class LogsPipelinesOrder(ModelNormal):
         """
         Object containing the ordered list of pipeline IDs.
 
-        :param pipeline_ids: Ordered Array of `<PIPELINE_ID>` strings, the order of pipeline IDs in the array
+        :param pipeline_ids: Ordered Array of ``<PIPELINE_ID>`` strings, the order of pipeline IDs in the array
             define the overall Pipelines order for Datadog.
         :type pipeline_ids: [str]
         """
