@@ -9,16 +9,11 @@ from datadog_api_client.model_utils import (
 )
 
 
-def lazy_import():
-    from datadog_api_client.v1.model.logs_string_builder_processor_type import LogsStringBuilderProcessorType
-
-    globals()["LogsStringBuilderProcessorType"] = LogsStringBuilderProcessorType
-
-
 class LogsStringBuilderProcessor(ModelNormal):
     @cached_property
     def openapi_types(_):
-        lazy_import()
+        from datadog_api_client.v1.model.logs_string_builder_processor_type import LogsStringBuilderProcessorType
+
         return {
             "is_enabled": (bool,),
             "is_replace_missing": (bool,),
@@ -43,21 +38,22 @@ class LogsStringBuilderProcessor(ModelNormal):
         to a log with the result of the provided template.
         This enables aggregation of different attributes or raw strings into a single attribute.
 
-        The template is defined by both raw text and blocks with the syntax `%{attribute_path}`.
+        The template is defined by both raw text and blocks with the syntax ``%{attribute_path}``.
 
-        **Notes**:
+        **Notes** :
 
-        - The processor only accepts attributes with values or an array of values in the blocks.
-        - If an attribute cannot be used (object or array of object),
+
+        * The processor only accepts attributes with values or an array of values in the blocks.
+        * If an attribute cannot be used (object or array of object),
           it is replaced by an empty string or the entire operation is skipped depending on your selection.
-        - If the target attribute already exists, it is overwritten by the result of the template.
-        - Results of the template cannot exceed 256 characters.
+        * If the target attribute already exists, it is overwritten by the result of the template.
+        * Results of the template cannot exceed 256 characters.
 
         :param is_enabled: Whether or not the processor is enabled.
         :type is_enabled: bool, optional
 
-        :param is_replace_missing: If true, it replaces all missing attributes of `template` by an empty string.
-            If `false` (default), skips the operation for missing attributes.
+        :param is_replace_missing: If true, it replaces all missing attributes of ``template`` by an empty string.
+            If ``false`` (default), skips the operation for missing attributes.
         :type is_replace_missing: bool, optional
 
         :param name: Name of the processor.
