@@ -3,18 +3,15 @@
 # Copyright 2019-Present Datadog, Inc.
 
 
-from datadog_api_client.v1.model_utils import (
+from datadog_api_client.model_utils import (
     ModelNormal,
     cached_property,
 )
 
 
 class MetricsListResponse(ModelNormal):
-
-    validations = {}
-
     @cached_property
-    def openapi_types():
+    def openapi_types(_):
         return {
             "_from": (str,),
             "metrics": ([str],),
@@ -25,8 +22,6 @@ class MetricsListResponse(ModelNormal):
         "metrics": "metrics",
     }
 
-    read_only_vars = {}
-
     def __init__(self, *args, **kwargs):
         """
         Object listing all metric names stored by Datadog since a given time.
