@@ -10,14 +10,6 @@ from datadog_api_client.model_utils import (
 )
 
 
-def lazy_import():
-    from datadog_api_client.v1.model.point import Point
-    from datadog_api_client.v1.model.metrics_query_unit import MetricsQueryUnit
-
-    globals()["Point"] = Point
-    globals()["MetricsQueryUnit"] = MetricsQueryUnit
-
-
 class MetricsQueryMetadata(ModelNormal):
     validations = {
         "unit": {
@@ -28,7 +20,9 @@ class MetricsQueryMetadata(ModelNormal):
 
     @cached_property
     def openapi_types(_):
-        lazy_import()
+        from datadog_api_client.v1.model.point import Point
+        from datadog_api_client.v1.model.metrics_query_unit import MetricsQueryUnit
+
         return {
             "aggr": (str, none_type),
             "display_name": (str,),
@@ -117,8 +111,8 @@ class MetricsQueryMetadata(ModelNormal):
         :type tag_set: [str], optional
 
         :param unit: Detailed information about the metric unit.
-            First element describes the "primary unit" (for example, `bytes` in `bytes per second`),
-            second describes the "per unit" (for example, `second` in `bytes per second`).
+            First element describes the "primary unit" (for example, ``bytes`` in ``bytes per second`` ),
+            second describes the "per unit" (for example, ``second`` in ``bytes per second`` ).
         :type unit: [MetricsQueryUnit], optional
         """
         super().__init__(kwargs)
