@@ -9,18 +9,13 @@ from datadog_api_client.model_utils import (
 )
 
 
-def lazy_import():
-    from datadog_api_client.v1.model.monitor_formula_and_function_event_aggregation import (
-        MonitorFormulaAndFunctionEventAggregation,
-    )
-
-    globals()["MonitorFormulaAndFunctionEventAggregation"] = MonitorFormulaAndFunctionEventAggregation
-
-
 class MonitorFormulaAndFunctionEventQueryDefinitionCompute(ModelNormal):
     @cached_property
     def openapi_types(_):
-        lazy_import()
+        from datadog_api_client.v1.model.monitor_formula_and_function_event_aggregation import (
+            MonitorFormulaAndFunctionEventAggregation,
+        )
+
         return {
             "aggregation": (MonitorFormulaAndFunctionEventAggregation,),
             "interval": (int,),
