@@ -10,16 +10,11 @@ from datadog_api_client.model_utils import (
 )
 
 
-def lazy_import():
-    from datadog_api_client.v1.model.monitor_overall_states import MonitorOverallStates
-
-    globals()["MonitorOverallStates"] = MonitorOverallStates
-
-
 class MonitorGroupSearchResult(ModelNormal):
     @cached_property
     def openapi_types(_):
-        lazy_import()
+        from datadog_api_client.v1.model.monitor_overall_states import MonitorOverallStates
+
         return {
             "group": (str,),
             "group_tags": ([str],),
