@@ -9,16 +9,11 @@ from datadog_api_client.model_utils import (
 )
 
 
-def lazy_import():
-    from datadog_api_client.v1.model.monitor_overall_states import MonitorOverallStates
-
-    globals()["MonitorOverallStates"] = MonitorOverallStates
-
-
 class MonitorStateGroup(ModelNormal):
     @cached_property
     def openapi_types(_):
-        lazy_import()
+        from datadog_api_client.v1.model.monitor_overall_states import MonitorOverallStates
+
         return {
             "last_nodata_ts": (int,),
             "last_notified_ts": (int,),
