@@ -3,7 +3,7 @@
 # Copyright 2019-Present Datadog, Inc.
 
 
-from datadog_api_client.v1.model_utils import (
+from datadog_api_client.model_utils import (
     ModelNormal,
     cached_property,
     none_type,
@@ -11,11 +11,8 @@ from datadog_api_client.v1.model_utils import (
 
 
 class MonitorThresholdWindowOptions(ModelNormal):
-
-    validations = {}
-
     @cached_property
-    def openapi_types():
+    def openapi_types(_):
         return {
             "recovery_window": (str, none_type),
             "trigger_window": (str, none_type),
@@ -26,8 +23,6 @@ class MonitorThresholdWindowOptions(ModelNormal):
         "trigger_window": "trigger_window",
     }
 
-    read_only_vars = {}
-
     def __init__(self, *args, **kwargs):
         """
         Alerting time window options.
