@@ -9,22 +9,14 @@ from datadog_api_client.model_utils import (
 )
 
 
-def lazy_import():
-    from datadog_api_client.v1.model.widget_text_align import WidgetTextAlign
-    from datadog_api_client.v1.model.widget_tick_edge import WidgetTickEdge
-    from datadog_api_client.v1.model.note_widget_definition_type import NoteWidgetDefinitionType
-    from datadog_api_client.v1.model.widget_vertical_align import WidgetVerticalAlign
-
-    globals()["WidgetTextAlign"] = WidgetTextAlign
-    globals()["WidgetTickEdge"] = WidgetTickEdge
-    globals()["NoteWidgetDefinitionType"] = NoteWidgetDefinitionType
-    globals()["WidgetVerticalAlign"] = WidgetVerticalAlign
-
-
 class NoteWidgetDefinition(ModelNormal):
     @cached_property
     def openapi_types(_):
-        lazy_import()
+        from datadog_api_client.v1.model.widget_text_align import WidgetTextAlign
+        from datadog_api_client.v1.model.widget_tick_edge import WidgetTickEdge
+        from datadog_api_client.v1.model.note_widget_definition_type import NoteWidgetDefinitionType
+        from datadog_api_client.v1.model.widget_vertical_align import WidgetVerticalAlign
+
         return {
             "background_color": (str,),
             "content": (str,),
