@@ -9,20 +9,13 @@ from datadog_api_client.model_utils import (
 )
 
 
-def lazy_import():
-    from datadog_api_client.v1.model.log_stream_widget_definition import LogStreamWidgetDefinition
-    from datadog_api_client.v1.model.notebook_graph_size import NotebookGraphSize
-    from datadog_api_client.v1.model.notebook_cell_time import NotebookCellTime
-
-    globals()["LogStreamWidgetDefinition"] = LogStreamWidgetDefinition
-    globals()["NotebookGraphSize"] = NotebookGraphSize
-    globals()["NotebookCellTime"] = NotebookCellTime
-
-
 class NotebookLogStreamCellAttributes(ModelNormal):
     @cached_property
     def openapi_types(_):
-        lazy_import()
+        from datadog_api_client.v1.model.log_stream_widget_definition import LogStreamWidgetDefinition
+        from datadog_api_client.v1.model.notebook_graph_size import NotebookGraphSize
+        from datadog_api_client.v1.model.notebook_cell_time import NotebookCellTime
+
         return {
             "definition": (LogStreamWidgetDefinition,),
             "graph_size": (NotebookGraphSize,),
@@ -37,7 +30,7 @@ class NotebookLogStreamCellAttributes(ModelNormal):
 
     def __init__(self, definition, *args, **kwargs):
         """
-        The attributes of a notebook `log_stream` cell.
+        The attributes of a notebook ``log_stream`` cell.
 
         :param definition: The Log Stream displays a log flow matching the defined query. Only available on FREE layout dashboards.
         :type definition: LogStreamWidgetDefinition
