@@ -9,16 +9,11 @@ from datadog_api_client.model_utils import (
 )
 
 
-def lazy_import():
-    from datadog_api_client.v1.model.notebook_markdown_cell_definition import NotebookMarkdownCellDefinition
-
-    globals()["NotebookMarkdownCellDefinition"] = NotebookMarkdownCellDefinition
-
-
 class NotebookMarkdownCellAttributes(ModelNormal):
     @cached_property
     def openapi_types(_):
-        lazy_import()
+        from datadog_api_client.v1.model.notebook_markdown_cell_definition import NotebookMarkdownCellDefinition
+
         return {
             "definition": (NotebookMarkdownCellDefinition,),
         }
@@ -29,9 +24,9 @@ class NotebookMarkdownCellAttributes(ModelNormal):
 
     def __init__(self, definition, *args, **kwargs):
         """
-        The attributes of a notebook `markdown` cell.
+        The attributes of a notebook ``markdown`` cell.
 
-        :param definition: Text in a notebook is formatted with [Markdown](https://daringfireball.net/projects/markdown/), which enables the use of headings, subheadings, links, images, lists, and code blocks.
+        :param definition: Text in a notebook is formatted with `Markdown <https://daringfireball.net/projects/markdown/>`_ , which enables the use of headings, subheadings, links, images, lists, and code blocks.
         :type definition: NotebookMarkdownCellDefinition
         """
         super().__init__(kwargs)
