@@ -9,16 +9,11 @@ from datadog_api_client.model_utils import (
 )
 
 
-def lazy_import():
-    from datadog_api_client.v1.model.notebook_response_data import NotebookResponseData
-
-    globals()["NotebookResponseData"] = NotebookResponseData
-
-
 class NotebookResponse(ModelNormal):
     @cached_property
     def openapi_types(_):
-        lazy_import()
+        from datadog_api_client.v1.model.notebook_response_data import NotebookResponseData
+
         return {
             "data": (NotebookResponseData,),
         }
