@@ -9,18 +9,12 @@ from datadog_api_client.model_utils import (
 )
 
 
-def lazy_import():
-    from datadog_api_client.v1.model.notebook_update_data_attributes import NotebookUpdateDataAttributes
-    from datadog_api_client.v1.model.notebook_resource_type import NotebookResourceType
-
-    globals()["NotebookUpdateDataAttributes"] = NotebookUpdateDataAttributes
-    globals()["NotebookResourceType"] = NotebookResourceType
-
-
 class NotebookUpdateData(ModelNormal):
     @cached_property
     def openapi_types(_):
-        lazy_import()
+        from datadog_api_client.v1.model.notebook_update_data_attributes import NotebookUpdateDataAttributes
+        from datadog_api_client.v1.model.notebook_resource_type import NotebookResourceType
+
         return {
             "attributes": (NotebookUpdateDataAttributes,),
             "type": (NotebookResourceType,),
