@@ -3,18 +3,15 @@
 # Copyright 2019-Present Datadog, Inc.
 
 
-from datadog_api_client.v1.model_utils import (
+from datadog_api_client.model_utils import (
     ModelNormal,
     cached_property,
 )
 
 
 class OrganizationSettingsSaml(ModelNormal):
-
-    validations = {}
-
     @cached_property
-    def openapi_types():
+    def openapi_types(_):
         return {
             "enabled": (bool,),
         }
@@ -23,8 +20,6 @@ class OrganizationSettingsSaml(ModelNormal):
         "enabled": "enabled",
     }
 
-    read_only_vars = {}
-
     def __init__(self, *args, **kwargs):
         """
         Set the boolean property enabled to enable or disable single sign on with SAML.
