@@ -9,16 +9,11 @@ from datadog_api_client.model_utils import (
 )
 
 
-def lazy_import():
-    from datadog_api_client.v1.model.scatterplot_dimension import ScatterplotDimension
-
-    globals()["ScatterplotDimension"] = ScatterplotDimension
-
-
 class ScatterplotWidgetFormula(ModelNormal):
     @cached_property
     def openapi_types(_):
-        lazy_import()
+        from datadog_api_client.v1.model.scatterplot_dimension import ScatterplotDimension
+
         return {
             "alias": (str,),
             "dimension": (ScatterplotDimension,),
