@@ -9,16 +9,11 @@ from datadog_api_client.model_utils import (
 )
 
 
-def lazy_import():
-    from datadog_api_client.v1.model.slo_error_timeframe import SLOErrorTimeframe
-
-    globals()["SLOErrorTimeframe"] = SLOErrorTimeframe
-
-
 class SLOBulkDeleteError(ModelNormal):
     @cached_property
     def openapi_types(_):
-        lazy_import()
+        from datadog_api_client.v1.model.slo_error_timeframe import SLOErrorTimeframe
+
         return {
             "id": (str,),
             "message": (str,),
