@@ -9,20 +9,14 @@ from datadog_api_client.model_utils import (
 )
 
 
-def lazy_import():
-    from datadog_api_client.v1.model.slo_correction_create_request_attributes import (
-        SLOCorrectionCreateRequestAttributes,
-    )
-    from datadog_api_client.v1.model.slo_correction_type import SLOCorrectionType
-
-    globals()["SLOCorrectionCreateRequestAttributes"] = SLOCorrectionCreateRequestAttributes
-    globals()["SLOCorrectionType"] = SLOCorrectionType
-
-
 class SLOCorrectionCreateData(ModelNormal):
     @cached_property
     def openapi_types(_):
-        lazy_import()
+        from datadog_api_client.v1.model.slo_correction_create_request_attributes import (
+            SLOCorrectionCreateRequestAttributes,
+        )
+        from datadog_api_client.v1.model.slo_correction_type import SLOCorrectionType
+
         return {
             "attributes": (SLOCorrectionCreateRequestAttributes,),
             "type": (SLOCorrectionType,),
