@@ -9,18 +9,12 @@ from datadog_api_client.model_utils import (
 )
 
 
-def lazy_import():
-    from datadog_api_client.v1.model.slo_correction import SLOCorrection
-    from datadog_api_client.v1.model.response_meta_attributes import ResponseMetaAttributes
-
-    globals()["SLOCorrection"] = SLOCorrection
-    globals()["ResponseMetaAttributes"] = ResponseMetaAttributes
-
-
 class SLOCorrectionListResponse(ModelNormal):
     @cached_property
     def openapi_types(_):
-        lazy_import()
+        from datadog_api_client.v1.model.slo_correction import SLOCorrection
+        from datadog_api_client.v1.model.response_meta_attributes import ResponseMetaAttributes
+
         return {
             "data": ([SLOCorrection],),
             "meta": (ResponseMetaAttributes,),
