@@ -9,20 +9,14 @@ from datadog_api_client.model_utils import (
 )
 
 
-def lazy_import():
-    from datadog_api_client.v1.model.slo_correction_update_request_attributes import (
-        SLOCorrectionUpdateRequestAttributes,
-    )
-    from datadog_api_client.v1.model.slo_correction_type import SLOCorrectionType
-
-    globals()["SLOCorrectionUpdateRequestAttributes"] = SLOCorrectionUpdateRequestAttributes
-    globals()["SLOCorrectionType"] = SLOCorrectionType
-
-
 class SLOCorrectionUpdateData(ModelNormal):
     @cached_property
     def openapi_types(_):
-        lazy_import()
+        from datadog_api_client.v1.model.slo_correction_update_request_attributes import (
+            SLOCorrectionUpdateRequestAttributes,
+        )
+        from datadog_api_client.v1.model.slo_correction_type import SLOCorrectionType
+
         return {
             "attributes": (SLOCorrectionUpdateRequestAttributes,),
             "type": (SLOCorrectionType,),
