@@ -3,18 +3,15 @@
 # Copyright 2019-Present Datadog, Inc.
 
 
-from datadog_api_client.v1.model_utils import (
+from datadog_api_client.model_utils import (
     ModelNormal,
     cached_property,
 )
 
 
 class SLODeleteResponse(ModelNormal):
-
-    validations = {}
-
     @cached_property
-    def openapi_types():
+    def openapi_types(_):
         return {
             "data": ([str],),
             "errors": ({str: (str,)},),
@@ -25,8 +22,6 @@ class SLODeleteResponse(ModelNormal):
         "errors": "errors",
     }
 
-    read_only_vars = {}
-
     def __init__(self, *args, **kwargs):
         """
         A response list of all service level objective deleted.
