@@ -37,22 +37,22 @@ class SLOHistoryMetricsSeriesMetadataUnit(ModelNormal):
         """
         An Object of metric units.
 
-        :param family: The family of metric unit, for example `bytes` is the family for `kibibyte`, `byte`, and `bit` units.
+        :param family: The family of metric unit, for example ``bytes`` is the family for ``kibibyte`` , ``byte`` , and ``bit`` units.
         :type family: str, optional
 
         :param id: The ID of the metric unit.
         :type id: int, optional
 
-        :param name: The unit of the metric, for instance `byte`.
+        :param name: The unit of the metric, for instance ``byte``.
         :type name: str, optional
 
-        :param plural: The plural Unit of metric, for instance `bytes`.
+        :param plural: The plural Unit of metric, for instance ``bytes``.
         :type plural: str, none_type, optional
 
-        :param scale_factor: The scale factor of metric unit, for instance `1.0`.
+        :param scale_factor: The scale factor of metric unit, for instance ``1.0``.
         :type scale_factor: float, optional
 
-        :param short_name: A shorter and abbreviated version of the metric unit, for instance `B`.
+        :param short_name: A shorter and abbreviated version of the metric unit, for instance ``B``.
         :type short_name: str, none_type, optional
         """
         super().__init__(kwargs)
