@@ -9,16 +9,11 @@ from datadog_api_client.model_utils import (
 )
 
 
-def lazy_import():
-    from datadog_api_client.v1.model.slo_timeframe import SLOTimeframe
-
-    globals()["SLOTimeframe"] = SLOTimeframe
-
-
 class SLOThreshold(ModelNormal):
     @cached_property
     def openapi_types(_):
-        lazy_import()
+        from datadog_api_client.v1.model.slo_timeframe import SLOTimeframe
+
         return {
             "target": (float,),
             "target_display": (str,),
@@ -44,7 +39,7 @@ class SLOThreshold(ModelNormal):
         :type target: float
 
         :param target_display: A string representation of the target that indicates its precision.
-            It uses trailing zeros to show significant decimal places (for example `98.00`).
+            It uses trailing zeros to show significant decimal places (for example ``98.00`` ).
 
             Always included in service level objective responses. Ignored in
             create/update requests.
@@ -57,7 +52,7 @@ class SLOThreshold(ModelNormal):
         :type warning: float, optional
 
         :param warning_display: A string representation of the warning target (see the description of
-            the `target_display` field for details).
+            the ``target_display`` field for details).
 
             Included in service level objective responses if a warning target exists.
             Ignored in create/update requests.
