@@ -9,16 +9,11 @@ from datadog_api_client.model_utils import (
 )
 
 
-def lazy_import():
-    from datadog_api_client.v1.model.synthetics_timing import SyntheticsTiming
-
-    globals()["SyntheticsTiming"] = SyntheticsTiming
-
-
 class SyntheticsAPITestResultShortResult(ModelNormal):
     @cached_property
     def openapi_types(_):
-        lazy_import()
+        from datadog_api_client.v1.model.synthetics_timing import SyntheticsTiming
+
         return {
             "passed": (bool,),
             "timings": (SyntheticsTiming,),
@@ -37,7 +32,7 @@ class SyntheticsAPITestResultShortResult(ModelNormal):
         :type passed: bool, optional
 
         :param timings: Object containing all metrics and their values collected for a Synthetic API test.
-            Learn more about those metrics in [Synthetics documentation](https://docs.datadoghq.com/synthetics/#metrics).
+            Learn more about those metrics in `Synthetics documentation <https://docs.datadoghq.com/synthetics/#metrics>`_.
         :type timings: SyntheticsTiming, optional
         """
         super().__init__(kwargs)
