@@ -9,16 +9,11 @@ from datadog_api_client.model_utils import (
 )
 
 
-def lazy_import():
-    from datadog_api_client.v1.model.synthetics_browser_error_type import SyntheticsBrowserErrorType
-
-    globals()["SyntheticsBrowserErrorType"] = SyntheticsBrowserErrorType
-
-
 class SyntheticsBrowserError(ModelNormal):
     @cached_property
     def openapi_types(_):
-        lazy_import()
+        from datadog_api_client.v1.model.synthetics_browser_error_type import SyntheticsBrowserErrorType
+
         return {
             "description": (str,),
             "name": (str,),
