@@ -9,18 +9,12 @@ from datadog_api_client.model_utils import (
 )
 
 
-def lazy_import():
-    from datadog_api_client.v1.model.synthetics_ci_batch_metadata_pipeline import SyntheticsCIBatchMetadataPipeline
-    from datadog_api_client.v1.model.synthetics_ci_batch_metadata_provider import SyntheticsCIBatchMetadataProvider
-
-    globals()["SyntheticsCIBatchMetadataPipeline"] = SyntheticsCIBatchMetadataPipeline
-    globals()["SyntheticsCIBatchMetadataProvider"] = SyntheticsCIBatchMetadataProvider
-
-
 class SyntheticsCIBatchMetadataCI(ModelNormal):
     @cached_property
     def openapi_types(_):
-        lazy_import()
+        from datadog_api_client.v1.model.synthetics_ci_batch_metadata_pipeline import SyntheticsCIBatchMetadataPipeline
+        from datadog_api_client.v1.model.synthetics_ci_batch_metadata_provider import SyntheticsCIBatchMetadataProvider
+
         return {
             "pipeline": (SyntheticsCIBatchMetadataPipeline,),
             "provider": (SyntheticsCIBatchMetadataProvider,),
