@@ -3,18 +3,15 @@
 # Copyright 2019-Present Datadog, Inc.
 
 
-from datadog_api_client.v1.model_utils import (
+from datadog_api_client.model_utils import (
     ModelNormal,
     cached_property,
 )
 
 
 class SyntheticsPrivateLocationCreationResponseResultEncryption(ModelNormal):
-
-    validations = {}
-
     @cached_property
-    def openapi_types():
+    def openapi_types(_):
         return {
             "id": (str,),
             "key": (str,),
@@ -25,8 +22,6 @@ class SyntheticsPrivateLocationCreationResponseResultEncryption(ModelNormal):
         "key": "key",
     }
 
-    read_only_vars = {}
-
     def __init__(self, *args, **kwargs):
         """
         Public key for the result encryption.
