@@ -9,22 +9,13 @@ from datadog_api_client.model_utils import (
 )
 
 
-def lazy_import():
-    from datadog_api_client.v1.model.synthetics_test_request_certificate_item import (
-        SyntheticsTestRequestCertificateItem,
-    )
-    from datadog_api_client.v1.model.synthetics_test_request_certificate_item import (
-        SyntheticsTestRequestCertificateItem,
-    )
-
-    globals()["SyntheticsTestRequestCertificateItem"] = SyntheticsTestRequestCertificateItem
-    globals()["SyntheticsTestRequestCertificateItem"] = SyntheticsTestRequestCertificateItem
-
-
 class SyntheticsTestRequestCertificate(ModelNormal):
     @cached_property
     def openapi_types(_):
-        lazy_import()
+        from datadog_api_client.v1.model.synthetics_test_request_certificate_item import (
+            SyntheticsTestRequestCertificateItem,
+        )
+
         return {
             "cert": (SyntheticsTestRequestCertificateItem,),
             "key": (SyntheticsTestRequestCertificateItem,),
