@@ -9,16 +9,11 @@ from datadog_api_client.model_utils import (
 )
 
 
-def lazy_import():
-    from datadog_api_client.v1.model.synthetics_ci_batch_metadata import SyntheticsCIBatchMetadata
-
-    globals()["SyntheticsCIBatchMetadata"] = SyntheticsCIBatchMetadata
-
-
 class SyntheticsTriggerTest(ModelNormal):
     @cached_property
     def openapi_types(_):
-        lazy_import()
+        from datadog_api_client.v1.model.synthetics_ci_batch_metadata import SyntheticsCIBatchMetadata
+
         return {
             "metadata": (SyntheticsCIBatchMetadata,),
             "public_id": (str,),
