@@ -3,18 +3,15 @@
 # Copyright 2019-Present Datadog, Inc.
 
 
-from datadog_api_client.v1.model_utils import (
+from datadog_api_client.model_utils import (
     ModelNormal,
     cached_property,
 )
 
 
 class TimeseriesWidgetExpressionAlias(ModelNormal):
-
-    validations = {}
-
     @cached_property
-    def openapi_types():
+    def openapi_types(_):
         return {
             "alias_name": (str,),
             "expression": (str,),
@@ -25,8 +22,6 @@ class TimeseriesWidgetExpressionAlias(ModelNormal):
         "expression": "expression",
     }
 
-    read_only_vars = {}
-
     def __init__(self, expression, *args, **kwargs):
         """
         Define an expression alias.
