@@ -9,20 +9,6 @@ from datadog_api_client.model_utils import (
 )
 
 
-def lazy_import():
-    from datadog_api_client.v1.model.tree_map_color_by import TreeMapColorBy
-    from datadog_api_client.v1.model.tree_map_group_by import TreeMapGroupBy
-    from datadog_api_client.v1.model.tree_map_widget_request import TreeMapWidgetRequest
-    from datadog_api_client.v1.model.tree_map_size_by import TreeMapSizeBy
-    from datadog_api_client.v1.model.tree_map_widget_definition_type import TreeMapWidgetDefinitionType
-
-    globals()["TreeMapColorBy"] = TreeMapColorBy
-    globals()["TreeMapGroupBy"] = TreeMapGroupBy
-    globals()["TreeMapWidgetRequest"] = TreeMapWidgetRequest
-    globals()["TreeMapSizeBy"] = TreeMapSizeBy
-    globals()["TreeMapWidgetDefinitionType"] = TreeMapWidgetDefinitionType
-
-
 class TreeMapWidgetDefinition(ModelNormal):
     validations = {
         "requests": {
@@ -33,41 +19,58 @@ class TreeMapWidgetDefinition(ModelNormal):
 
     @cached_property
     def openapi_types(_):
-        lazy_import()
+        from datadog_api_client.v1.model.tree_map_color_by import TreeMapColorBy
+        from datadog_api_client.v1.model.widget_custom_link import WidgetCustomLink
+        from datadog_api_client.v1.model.tree_map_group_by import TreeMapGroupBy
+        from datadog_api_client.v1.model.tree_map_widget_request import TreeMapWidgetRequest
+        from datadog_api_client.v1.model.tree_map_size_by import TreeMapSizeBy
+        from datadog_api_client.v1.model.widget_time import WidgetTime
+        from datadog_api_client.v1.model.tree_map_widget_definition_type import TreeMapWidgetDefinitionType
+
         return {
             "color_by": (TreeMapColorBy,),
+            "custom_links": ([WidgetCustomLink],),
             "group_by": (TreeMapGroupBy,),
             "requests": ([TreeMapWidgetRequest],),
             "size_by": (TreeMapSizeBy,),
+            "time": (WidgetTime,),
             "title": (str,),
             "type": (TreeMapWidgetDefinitionType,),
         }
 
     attribute_map = {
         "color_by": "color_by",
+        "custom_links": "custom_links",
         "group_by": "group_by",
         "requests": "requests",
         "size_by": "size_by",
+        "time": "time",
         "title": "title",
         "type": "type",
     }
 
     def __init__(self, requests, type, *args, **kwargs):
         """
-        The treemap visualization found on the Host Dashboards comes from the output of `ps auxww`. This is not continuously run on your hosts. Instead, it’s run once on Agent start/restart. The treemap is only supported for process data on a single host dashboard — this may not be reused in other dashboards or for other metrics.
+        The treemap visualization enables you to display hierarchical and nested data. It is well suited for queries that describe part-whole relationships, such as resource usage by availability zone, data center, or team.
 
-        :param color_by: The attribute used to determine color in the widget.
+        :param color_by: (deprecated) The attribute formerly used to determine color in the widget.
         :type color_by: TreeMapColorBy, optional
 
-        :param group_by: The attribute used to group elements in the widget.
+        :param custom_links: List of custom links.
+        :type custom_links: [WidgetCustomLink], optional
+
+        :param group_by: (deprecated) The attribute formerly used to group elements in the widget.
         :type group_by: TreeMapGroupBy, optional
 
-        :param requests: List of top list widget requests.
+        :param requests: List of treemap widget requests.
         :type requests: [TreeMapWidgetRequest]
 
-        :param size_by: The attribute used to determine size in the widget.
+        :param size_by: (deprecated) The attribute formerly used to determine size in the widget.
         :type size_by: TreeMapSizeBy, optional
 
+        :param time: Time setting for the widget.
+        :type time: WidgetTime, optional
+
         :param title: Title of your widget.
         :type title: str, optional
 
