@@ -16,7 +16,11 @@ class UsageAttributionTagNames(ModelNormal):
 
     def __init__(self, *args, **kwargs):
         """
-        Usage Summary by tag name.
+        Tag keys and values.
+
+        A ``null`` value here means that the requested tag breakdown cannot be applied because it does not match the `tags
+        configured for usage attribution <https://docs.datadoghq.com/account_management/billing/usage_attribution/#getting-started>`_.
+        In this scenario the API returns the total usage, not broken down by tags.
         """
         super().__init__(kwargs)
 
